<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>Dokumentfremviser</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>Dokumentviewer er et værktøj til at læse dokumentfiler, som PDF, DJVU, DOCX osv.</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>Placering</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>Emne</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>Nøgleord</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>Producent</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>Skaber</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>Oprettelsestidspunkt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>Ændringstidspunkt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>Sider</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>Optimeret</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>Sidestøttelse</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>Filstørrelse</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>Grundlæggende information</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>Tilføj bogmærke</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>Er du sikker på, at du vil slette alle bogmærker?</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>Fjern annotering</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <source>Add annotation</source>
        <translation>Tilføj annotering</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <source>Remove bookmark</source>
        <translation>Fjern bogmærke</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <source>Add bookmark</source>
        <translation>Tilføj bogmærke</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>Fremhæv</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>Fjern fremhævning</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <source>Exit fullscreen</source>
        <translation>Afslut fuldskærm</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <source>Slide show</source>
        <translation>Slideshow</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <source>First page</source>
        <translation>Første side</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <source>Previous page</source>
        <translation>Forrige side</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <source>Next page</source>
        <translation>Næste side</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <source>Last page</source>
        <translation>Sidste side</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <source>Rotate left</source>
        <translation>Drej til venstre</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <source>Rotate right</source>
        <translation>Drej til højre</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <source>Document info</source>
        <translation>Dokumentinformation</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="147"/>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>Formatet understøttes ikke</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>Åbning mislykkedes</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>Tjek venligst om filen er beskadiget</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>Konvertering mislykkedes, tjek venligst om filen er skadet</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>Kunne ikke gemme</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>Gemt</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <source>Invalid file name</source>
        <translation>Ugyldigt filnavn</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>Træk dokumenter her</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>Støttet format: %1</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>Vælg fil</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="332"/>
        <source>The bookmark has been removed</source>
        <translation>Bogmærket er fjernet</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="533"/>
        <source>Please select the text</source>
        <translation>Vælg venligst teksten</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="598"/>
        <source>The annotation has been removed</source>
        <translation>Annoteringen er fjernet</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Krypteret fil, indtast venligst adgangskode</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>Forkert adgangskode</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="127"/>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="135"/>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>Vælg tekst</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>Håndværktøj</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>Tilføj annotering</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>Er du sikker på, at du vil slette alle noter?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>Ugyldigt sidetal</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>Konverterer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>Dokument ikke gemt</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to "%1"?</source>
        <translation>Gem ændringerne til "%1"?</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>Forkast</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>Tosidet visning</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>1:1 størrelse</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>Passer side</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>Tilpas højde</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>Tilpas bredde</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>Ingen søgeresultater</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="111"/>
        <source>%1 items found</source>
        <translation>%1 elementer fundet</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>Denne dokument er ved at forbinde til:</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>Hvis du er sikker på webstedet, klik på Tillad, ellers klik på Blokér.</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>Blokér</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>Tillad</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>Miniaturer</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>Bogmærker</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>Annoteringer</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="60"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="124"/>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Page up</source>
        <translation>Side op</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="121"/>
        <source>Page down</source>
        <translation>Side ned</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="105"/>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="118"/>
        <source>Zoom in</source>
        <translation>Zoom ind</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="119"/>
        <source>Zoom out</source>
        <translation>Zoom ud</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="106"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="107"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="108"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="112"/>
        <source>Thumbnails</source>
        <translation>Miniaturer</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="113"/>
        <source>1:1 size</source>
        <translation>1:1 størrelse</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="114"/>
        <source>Fit height</source>
        <translation>Tilpas højde</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="115"/>
        <source>Fit width</source>
        <translation>Tilpas bredde</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="116"/>
        <source>Rotate left</source>
        <translation>Drej til venstre</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="117"/>
        <source>Rotate right</source>
        <translation>Drej til højre</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="122"/>
        <source>Move to the beginning</source>
        <translation>Flyt til starten</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="123"/>
        <source>Move to the end</source>
        <translation>Flyt til slutningen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="128"/>
        <source>Select text</source>
        <translation>Vælg tekst</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="129"/>
        <source>Hand tool</source>
        <translation>Håndværktøj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="130"/>
        <source>Add bookmark</source>
        <translation>Tilføj bogmærke</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="143"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="133"/>
        <source>Magnifier</source>
        <translation>Forstørrelsesglas</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="135"/>
        <source>Slide show</source>
        <translation>Slideshow</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="136"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="140"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="141"/>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="144"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="145"/>
        <source>Select all</source>
        <translation>Vælg alt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="101"/>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="131"/>
        <source>Add annotation</source>
        <translation>Tilføj annotering</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="132"/>
        <source>Highlight</source>
        <translation>Fremhæv</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="134"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>Fjern annotering</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <source>Remove all</source>
        <translation>Fjern alt</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>Fjern bogmærke</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>Side %1</translation>
    </message>
</context>
<context>
    <name>SlidePlayWidget</name>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
        <source>It is the first page</source>
        <translation>Det er den første side</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
        <source>It is the last page</source>
        <translation>Det er den sidste side</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>Nyt vindue</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>Nyt faneblad</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>Forstørrelsesglas</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>Værktøjer</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>Miniaturer</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>Inputgrænse nået</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Dokumentfilsti.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <source>FilePath</source>
        <translation>Filsti</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>ThumbnailPath-sti.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Generer thumbnail.</translation>
    </message>
</context>
</TS>
